@@ -1,6 +1,7 @@
 package utils
 
 import (
+	"bytes"
 	"encoding/xml"
 	"fmt"
 	"github.com/PuerkitoBio/goquery"
@@ -24,7 +25,6 @@ const (
 func FormatXml(reader io.Reader, writer io.Writer, indent string, colors int) error {
 	decoder := xml.NewDecoder(reader)
 	decoder.Strict = false
-	decoder.AutoClose = xml.HTMLAutoClose
 	decoder.CharsetReader = func(charset string, input io.Reader) (io.Reader, error) {
 		e, err := ianaindex.MIME.Encoding(charset)
 		if err != nil {
@@ -86,7 +86,9 @@ func FormatXml(reader io.Reader, writer io.Writer, indent string, colors int) er
 				if attr.Name.Local == "xmlns" {
 					nsAliases[attr.Value] = ""
 				}
-				attrs = append(attrs, getTokenFullName(attr.Name, nsAliases)+attrColor("=\""+attr.Value+"\""))
+				escapedValue, _ := escapeText(attr.Value)
+				attrElement := getTokenFullName(attr.Name, nsAliases) + attrColor("=\""+escapedValue+"\"")
+				attrs = append(attrs, attrElement)
 			}
 			attrsStr := strings.Join(attrs, " ")
 			if attrsStr != "" {
@@ -147,6 +149,9 @@ func FormatXml(reader io.Reader, writer io.Writer, indent string, colors int) er
 			}
 			hasContent = false
 			lastTagName = currentTagName
+		case xml.Directive:
+			_, _ = fmt.Fprint(writer, tagColor("<!"), string(typedToken), tagColor(">"))
+			_, _ = fmt.Fprint(writer, "\n", strings.Repeat(indent, level))
 		default:
 		}
 	}
@@ -246,7 +251,8 @@ func FormatHtml(reader io.Reader, writer io.Writer, indent string, colors int) e
 			if hasAttr {
 				for {
 					attrKey, attrValue, moreAttr := tokenizer.TagAttr()
-					attrs = append(attrs, string(attrKey)+attrColor("=\""+string(attrValue)+"\""))
+					escapedValue, _ := escapeText(string(attrValue))
+					attrs = append(attrs, string(attrKey)+attrColor("=\""+escapedValue+"\""))
 					if !moreAttr {
 						break
 					}
@@ -358,3 +364,16 @@ func getSelfClosingTags() map[string]bool {
 		"wbr":    true,
 	}
 }
+
+func escapeText(input string) (string, error) {
+	buf := new(bytes.Buffer)
+	if err := xml.EscapeText(buf, []byte(input)); err != nil {
+		return "", err
+	}
+
+	result := buf.String()
+	result = strings.Replace(result, "&#34;", "&quot;", -1)
+	result = strings.Replace(result, "&#39;", "&apos;", -1)
+
+	return result, nil
+}
